@@ -1,40 +1,32 @@
 package Dancer::Template::MicroTemplate;
 
+# ABSTRACT: Text::MicroTemplate engine for Dancer
+
 use strict;
 use warnings;
 
 use Text::MicroTemplate::File;
-use Dancer::ModuleLoader;
-use Dancer::FileUtils 'path';
 
 use vars '$VERSION';
 use base 'Dancer::Template::Abstract';
 
-$VERSION = '0.1';
+$VERSION = '1.0.0';
 
 my $_engine;
 
 sub init {
     my $self = shift;
 
-    my $mt_cfg = {
-        use_cache  => 0,
-        tag_start  => '<%',
-        tag_end    => '%>',
-        line_start => '%',
-    };
-    my $path = path($self->{settings}{appdir}, 'views');
-    $mt_cfg->{include_path} = [$path]
-      if $self->{settings} && $self->{settings}{appdir};
+    my %mt_cfg = (%{ $self->config });
 
-    $_engine = Text::MicroTemplate::File->new(%$mt_cfg);
+    $_engine = Text::MicroTemplate::File->new(%mt_cfg);
 }
 
 sub render($$$) {
     my ($self, $template, $tokens) = @_;
 
     die "'$template' is not a regular file"
-      if ref($template) || (!-f $template);
+        if ref($template) || (!-f $template);
 
     my $content = "";
     $content = $_engine->render_file($template, $tokens)->as_string;
@@ -42,13 +34,10 @@ sub render($$$) {
 }
 
 1;
-__END__
-
-=pod
 
 =head1 NAME
 
-Dancer::Template::MicroTemplate - MicroTemplate wrapper for Dancer
+Dancer::Template::MicroTemplate - Text::MicroTemplate engine for Dancer
 
 =head1 DESCRIPTION
 
@@ -60,7 +49,7 @@ In order to use this engine, set the following setting as the following:
     template: micro_template
 
 This can be done in your config.yml file or directly in your app code with the
-B<set> keyword.
+C<set> keyword.
 
 =head1 SEE ALSO
 
@@ -68,11 +57,11 @@ L<Dancer>, L<Text::MicroTemplate>
 
 =head1 AUTHOR
 
-This module has been written by Franck Cuny
+This module has been written by Franck Cuny and James Aitken
 
 =head1 LICENSE
 
-This module is free software and is released under the same terms as Perl
-itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
